#
# spec file for package filezilla
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libversion 3.68.0
%define libfilezillaversion 0.49.0

Name:           filezilla
Version:        3.68.0
Release:        1.6
Summary:        A GUI FTP and SFTP Client
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Ftp/Clients
URL:            https://filezilla-project.org/
#Source0:        https://download.filezilla-project.org/client/FileZilla_%%{version}_src.tar.xz
Source0:        FileZilla_%{version}_src.tar.xz
Patch0:         %{name}-welcome_dialog.patch
Patch1:         disable-avx-on-i586.patch
Patch3:         %{name}-sftp_crypt_info_dlg.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
%if 0%{?suse_version} > 1500
BuildRequires:  libboost_regex-devel >= 1.76.0
%else
BuildRequires:  libboost_regex-devel-impl >= 1.76.0
%endif
BuildRequires:  libtool
BuildRequires:  pkgconfig
# needs long long support in pugixml
BuildRequires:  pugixml-devel >= 1.7
BuildRequires:  update-desktop-files
#BuildRequires:  wxWidgets-3_2-devel >= 3.2.1
BuildRequires:  wxGTK3-3_2-devel
BuildRequires:  xdg-utils
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(dbus-1)
#BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libfilezilla) >= %{libfilezillaversion}
BuildRequires:  pkgconfig(libidn)
BuildRequires:  pkgconfig(nettle) >= 3.1
BuildRequires:  pkgconfig(sqlite3) >= 3.7.0
# See boo#966384 filezilla fails to start
Requires:       libpugixml1 >= 1.7
# upstream use gnutls 3.8.0
%if 0%{?suse_version} > 1500
BuildRequires:  pkgconfig(gnutls) >= 3.7.9
%else
BuildRequires:  pkgconfig(gnutls) >= 3.7.3
%endif

%description
FileZilla is a modern and powerful FTP client.
FileZilla development focuses on high usability while also
supporting as many useful features as possible.

Some of the main features are:
 * Continuing interrupted up-/downloads.
 * Managing different FTP sites.
 * Modifiable Commands.
 * Keep-Alive-System.
 * Timeout detection.
 * Firewall support.
 * SOCKS4/5 and HTTP 1.1 proxy support.
 * SSL support (secure connections).
 * SFTP support.
 * Upload/Download queue.
 * Drag&Drop support.

%package devel
Summary:        Development files for filezilla
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This are development files for filezilla.

%lang_package

%prep
%autosetup -p1

%build
autoreconf -fi
%configure \
  --disable-static            \
  --disable-manualupdatecheck \
  --disable-autoupdatecheck   \
  --with-dbus
%make_build

%install
%make_install
%suse_update_desktop_file %{name}
%fdupes %{buildroot}%{_datadir}/
%find_lang %{name}

%check
%make_build check

%post -p /sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post

%postun -p /sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun

%files
%license COPYING
%doc README NEWS
%{_bindir}/%{name}
%{_bindir}/fzsftp
%{_bindir}/fzputtygen
%{_datadir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/icons/hicolor/480x480
%dir %{_datadir}/icons/hicolor/480x480/apps
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/pixmaps/%{name}.png
%dir %{_datadir}/appdata/
%{_datadir}/appdata/%{name}.appdata.xml
%{_libdir}/libfzclient-commonui-private-%{libversion}.so
%{_libdir}/libfzclient-private-%{libversion}.so
%{_mandir}/man1/filezilla.1%{?ext_man}
%{_mandir}/man1/fzputtygen.1%{?ext_man}
%{_mandir}/man1/fzsftp.1%{?ext_man}
%{_mandir}/man5/fzdefaults.xml.5%{?ext_man}

%files devel
%{_libdir}/libfzclient-commonui-private.la
%{_libdir}/libfzclient-commonui-private.so
%{_libdir}/libfzclient-private.la
%{_libdir}/libfzclient-private.so

%files lang -f %{name}.lang

%changelog
* Sat Nov  2 2024 ecsos <ecsos@opensuse.org>
- Update to 3.68.0
  * New features:
  - Added option to always refresh remote directory listings when
    starting a recursive operation
  * Bugfixes and minor changes:
  - Changing logfile settings no longer requires a restart of
    FileZilla
  - Fixed a display issue with special characters in usernames
  - MSW: Fixed local file list not updating after renaming or
    deleting items
  - SFTP: Update interval of transfer progress during uploads
    should now be more consistent on very slow connections
  - Updated to libfilezilla 0.49.0
* Mon Oct 28 2024 ecsos <ecsos@opensuse.org>
- Switch from BuildRequires wxWidgets-3_2-devel and gtk+-2.0 to
  wxGTK3-3_2-devel and gtk+-3.0 to fix   the boo#1231757 bug.
* Fri Jul 12 2024 ecsos <ecsos@opensuse.org>
- Update to 3.67.1
  * Bugfixes and minor changes:
  - MSW: Fixed an issue with confirmation dialogs for file
    deletion not being modal
  - Updated to libfilezilla 0.48.1
- Changes from 3.67.1-rc1
  * Bugfixes and minor changes:
  - Fixed an issue migrating old queue files if several older
    versions have been skipped
  - Updated to libfilezilla 0.48.0
- Drop filezilla-verifyhostkeydialog.patch because now in upstream.
- Download over osc no more possible. Source must be download over
  website link.
* Thu Apr 18 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Do not recommend filezilla-lang: the -lang package, as generated
  by %%lang_package, already contains more sophisticated
  supplements.
* Wed Apr 17 2024 ecsos <ecsos@opensuse.org>
- Update to 3.67.0
  * Fixed vulnerabilities:
  - SFTP: Fixed PuTTY ECDSA NIST P-521 private key recovery
    vulnerability (CVE-2024-31497).
    If you use NIST P-521 keys to connect to SSH/SFTP servers,
    you should regenerate them and revoke the previous ones.
  - Official binaries are now built against GnuTLS 3.8.4
  * Bugfixes and minor changes:
  - Updated to libfilezilla 0.47.0
- Fix boo#1222871 - (CVE-2024-31497)
- Add filezilla-verifyhostkeydialog.patch to fix build error.
- Add filezilla-sftp_crypt_info_dlg.patch to fix build error.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.66.5:
  + Updated to libfilezilla 0.46.0
  + MSW: Fixed tab navigation over message log
- Changes from version 3.66.4:
  + SFTP: Address Terrapin protocol vulerability
- Changes from version 3.66.3-rc1:
  + Test release for macOS CPU architecture migration.
- Changes from version 3.66.3-beta1:
  + Fixed a potential crash in the HTTP client
* Sat Dec  2 2023 ecsos <ecsos@opensuse.org>
- Update to 3.66.1
  * Bugfixes and minor changes:
  - macOS: Fixed display of local filenames containing non-ASCII
    characters if LC_CTYPE wasn't set
* Tue Oct 24 2023 ecsos <ecsos@opensuse.org>
- Update to 3.66.0
  * Bugfixes and minor changes:
  - Fixed a sorting issue in comparative search
- Changes from 3.66.0-rc1
  * Bugfixes and minor changes:
  - Fixed crash removing items from the list of file extensions
    treated as text files
  - Fixed potental crash if shutting down HTTP client.
  - Fixed HTTP timeouts
* Wed Jul 12 2023 ecsos <ecsos@opensuse.org>
- Update to 3.65.0
  * New features:
  - Comparative search can now also be used if sorted by path
  * Bugfixes and minor changes:
  - Fixed an issue in comparative search in directories with
    uppercase letters
- Changes from 3.65.0-rc1
  * Bugfixes and minor changes:
  - Fixed potential crashes
  - Updated to libfilezilla 0.44.0
* Sat Jun  3 2023 ecsos <ecsos@opensuse.org>
- Update to 3.64.0
  - Fixed refresh of directory trees when filters changing
  - Updated to libfilezilla 0.42.2
- Changes from 3.64.0-rc1
  - MSW: Additional icon sizing fixes on high DPI scale factors
  - Updated to libfilezilla 0.42.0
  - Switched to .tar.xz for source tarballs
* Wed Apr 12 2023 ecsos <ecsos@opensuse.org>
- Fix build error for Tumbleweed.
* Sat Mar  4 2023 ecsos <ecsos@opensuse.org>
- Update to 3.63.2.1
  * Bugfixes and minor changes:
  - macOS: Several rendering fixes in dark mode
  - macOS: Disable automatic quote/dash substitution in text
    input fields
  - MSW: Fixed an issue with Drag&Drop to Explorer on systems
    that use shortened 8.3 pathnames in environment variables
  - MSW: If FileZilla was installed for current user only,
    updating with the installer now skips the UAC prompt
  - Updated to libfilezilla 0.41.1 to fix a rare crash
  - Official binaries are now built againt GnuTLS 3.8.0
* Fri Feb 24 2023 ecsos <ecsos@opensuse.org>
- Update to 3.63.2
  * Bugfixes and minor changes:
  - macOS: Several rendering fixes in dark mode
  - macOS: Disable automatic quote/dash substitution in text
    input fields
  - MSW: Fixed an issue with Drag&Drop to Explorer on systems
    that use shortened 8.3 pathnames in environment variables
  - MSW: If FileZilla was installed for current user only,
    updating with the installer now skips the UAC prompt
  - Updated to libfilezilla 0.41.1 to fix a rare crash
  - Official binaries are now built againt GnuTLS 3.8.0
* Sun Jan 29 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 3.63.1:
  * MSW: Fixed icon sizing issues on high DPI scale factors
* Wed Jan 25 2023 ecsos <ecsos@opensuse.org>
- Update to 3.63.0
  * Bugfixes and minor changes:
  - All official FileZilla binares now link against wxWidgets 3.2.1
  - Fixed a potential crash when closing FileZilla
- Changes from 3.62.2
  * Bugfixes and minor changes:
  - Fixed an issue with some dialogs not showing up
* Fri Nov 18 2022 ecsos <ecsos@opensuse.org>
- Update to 3.62.1
  * Bugfixes and minor changes:
  - Fixed a crash if main menu events arrive while a dialog is
    already open
  - macOS: Fixed an issue with keyboard shortcuts
  - macOS: Fix selected item count in file list status bars
  - macOS: Fixed graphical corruption in some controls
- Changes from 3.62.0
  * Bugfixes and minor changes:
  - Fixed sizing issues in about and welcome dialogs
- Changes from 3.62.0-beta1
  * Bugfixes and minor changes:
  - macOS binaries are now built against wxWidgets 3.2.1
  - updated to libfilezilla 0.39.2
* Sat Sep 24 2022 ecsos <ecsos@opensuse.org>
- Update to 3.61.0
  * Bugfixes and minor changes:
  - Updated to libfilezilla 0.39.1
- Changes from 3.61.0-beta1
  * New features:
  - Use improved asynchronous file readers/writers from
    libfilezilla
  * Bugfixes and minor changes:
  - Fix export of root items in the Site Manager
  - Handle rare cases of non-existing download directory in the
    updater
* Sat Jul 23 2022 ecsos <ecsos@opensuse.org>
- Update to 3.60.2
  * Bugfixes and minor changes:
  - Updated to libfilezilla 0.38.1 to address an issue with child
    process termination resulting in freezes
* Tue Jun 14 2022 Dirk Müller <dmueller@suse.com>
- update to 3.60.1:
  * Fixed a regression drag-moving local files
- add disable-avx-on-i586.patch to disable avx on 32bit platforms
* Sat May 28 2022 ecsos <ecsos@opensuse.org>
- Update to 3.60.0
  * Bugfixes and minor changes:
  - SFTP: Fixed error handling if reading from child process fails
  - Fixed transfers following recursive operations not starting
    if the connection limit has been set to 1 in the Site Manager
- Changes from 3.60.0-rc1
  * New features:
  - macOS: Remote files can now be dragged into Finder
  * Bugfixes and minor changes:
  - Fixed file change detection when editing files
- Use gcc10-c++ in Tumbleweed to fix build error for Tumbleweed i586.
* Fri Apr  8 2022 ecsos <ecsos@opensuse.org>
- Update to 3.59.0
  * Bugfixes and minor changes:
  - Windows binaries: Updated zlib, used purely to cache
    re-scaled versions of icons shipped with FileZilla, to 1.2.12
  - Updated to libfilezilla 0.37.1
- Changes from 3.59.0-rc1
  * Bugfixes and minor changes:
  - Updated to libfilezilla 0.37.0
  - Non-blocking communication with SFTP process
  - macOS, *nix: Fixed "All files" category in file picker dialogs
- Changes from 3.58.0
  * Bugfixes and minor changes:
  - More detailed error messages if an XML file known to exist
    cannot be opened
- Changes from 3.58.0-rc1
  * New features:
  - Negotiate custom ALPN with FileZilla Server >=1.3.0 during
    TLS handshake to save some roundtrips during connection
    establishment
  - Prepare FileZilla to support TOTP-based 2FA authentication on
    future FileZilla Server versions
  * Bugfixes and minor changes:
  - Made downloading updates more robust if the network
    connection is unreliable
  - Updated to libfilezilla 0.36.0
* Sun Dec 12 2021 ecsos <ecsos@opensuse.org>
- Update to 3.57.0
  * Bugfixes and minor changes:
  - Fixed incorrect default settings for file editing
  - Fixed a crash looking up data in file lists
  - Fixed a crash if a HTTPS connection gets canceled during the
    TLS handshake
  - Updated to libfilezilla 0.35.0
* Sat Nov  6 2021 ecsos <ecsos@opensuse.org>
- Update to 3.56.2
  * Bugfixes and minor changes:
  - Fixed a potential crash after uploading
- Changes from 3.56.1
  * Bugfixes and minor changes:
  - macOS Monterey: Opening the Site Manager on startup is now
    delayed a millisecond, otherwise the right mouse button would
    have stopped working
  - macOS: Fixed getting temporary directory
  - MSW: Updated to libfilezilla 0.34.1 to fix local directory
    contents returned by the system in oversized buffers
    containing nulls
- Rebase filezilla-welcome_dialog.patch.
* Sat Aug 14 2021 Jan Engelhardt <jengelh@inai.de>
- Rework filezilla-welcome_dialog.patch to keep the footer text
  rather than killing it.
* Thu Aug 12 2021 ecsos <ecsos@opensuse.org>
- Update to 3.55.1
  * Bugfixes and minor changes:
  - Fixed a crash if a tree view items are deleted at the same
    time as something is being dragged over the tree view
  - Updated to libfilezilla 0.31.1 to fix an issue with SIGPIPE
    on *nix
- Add filezilla-welcome_dialog.patch to fix build error:
  welcome_dialog.cpp:122:26: error: operands to '?:' have different
  types 'wxString' and 'const std::__cxx11::basic_string<wchar_t>'
* Wed May 19 2021 ecsos <ecsos@opensuse.org>
- Update to 3.54.1
  * Bugfixes and minor changes:
  - Fix control visibility logic in Site Manager
- Changes from 3.54.0
  * Bugfixes and minor changes:
  - SFTP: Fixed a regression loading configured key files
- Changes from 3.54.0-rc1:
  * Bugfixes and minor changes:
  - Refactored network activity handling, the activity indicators
    tooltips now display more accurate data
  - Updated SFTP components
  - Small performance improvement sorting very large directory
    listings
  - Fixed a crash changing numeric permissions value in chmod
    dialog
* Tue Mar 23 2021 ecsos <ecsos@opensuse.org>
- Update to 3.53.1
  * Bugfixes and minor changes:
  - Removed an error message on new installation where there is
    no sitemanager.xml yet
  - Fixed SOCKS5 proxy support
* Sat Mar 20 2021 ecsos <ecsos@opensuse.org>
- Update to 3.53.0
  * Bugfixes and minor changes:
  - HTTP: Handle servers sending early replies
- Changes from 3.53.0-rc1:
  * New features:
  - Require explicit confirmation on FTP servers not supporting
    TLS session esumption on the data connection
  - Access Grant support for Tardigrade
  * Bugfixes and minor changes:
  - MSW: Fixed handle leak if using SFTP
  - FTP: Fixed cancelling listings on very slow computers with
    extremely fast network connection
  - Fixed loading of custom FTP proxy setting when opening the
    settings dialog
  - Internal restructuring
- Fix boo#1183820
* Wed Jan 20 2021 ecsos <ecsos@opensuse.org>
- Update to 3.52.2
  - When restoring the main window position at startup, detect if
    the title bar would become hidden behind taskbars or global
    menu bars and reposition it appropriately
  - SFTP: Fixed preserving of timestamps on downloads
* Sun Jan 10 2021 ecsos <ecsos@opensuse.org>
- Update to 3.52.0.5
  * Bugfixes and minor changes:
  - FTP: Fixed crash if downloading ASCII files with stray
    carriage returns
  - Fixed too strict requirements for preallocation
  - *nix: Fixed a memory leak
- Changes from 3.52.0.4
  * Bugfixes and minor changes:
  - macOS: Work around a kernel bug where ftruncate cannot be
    called more than once on a shared memory object
- Changes from 3.52.0.3
  * Bugfixes and minor changes:
  - macOS: Fix issue opening shared memory objects
  - Use locale-safe name for shm_open, omit padding.
- Changes from 3.52.0.2
  * Bugfixes and minor changes:
  - HTTP: Handle multi-token Connection: headers
  - It appears the Connection: header can have multiple tokens.
    Take this into account deciding whether persistent
    connections are used.
  - Remove unused variable
- Changes from 3.52.0.1
  * Bugfixes and minor changes:
  - macOS: Rebuilt to address a toolchain issue
  - Updated translation
  - Use proper toolbar style. Apple should fire all UI designers.
  - Fixed warnings.
- Changes from 3.52.0
  * Bugfixes and minor changes:
  - Fixed a regression with the rename file exists action on
    downloads
  - Fixed warnings.
  - Minor refactoring
  - Fix rename file exists action on downloads.
  - Updated translations
* Wed Oct 21 2020 ecsos <ecsos@opensuse.org>
- Update to 3.51.0:
  * Bugfixes and minor changes:
  - Fixed import of sites protected with a different master password
  - Directory comparison now works correctly with non-default file name sorting settings
  - Small search dialog fixes
- Changes from 3.51.0-rc1:
  * Bugfixes and minor changes:
  - Refactored how the queue stores transfer flags
  - Refactored internals to be more modular
  - Linux: Disable receive buffer tuning if it results in unexpected consequences
  - Distinguish between Cancel and No in the file changed dialog
  - Small fixes to changing or disabling a master password
* Mon Sep  7 2020 ecsos <ecsos@opensuse.org>
- Update to 3.50.0:
  * Bugfixes and minor changes:
  - Minor fixes to Tardigrade integration
- Changes from 3.50.0-rc1:
  * New features:
  - Update Storj/Tardigrade integration, now based on the
    uplink-c library
  * Bugfixes and minor changes:
  - Fix layout issues in the Site Manager if switching protocol
  - Restored natural sort option for file list sorting
* Sat Aug 22 2020 ecsos <ecsos@opensuse.org>
- Fix libfilezilla requirement version.
* Sun Aug 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 3.49.1:
  - Fixed selection changes not being reflected in the Site Manager in some circumstances
  - Fixed retrying initial connection attempts
  - MSW: Tab bar icons now scale on high-DPI displays
  - The sizing and spacing of several dialogs has been improved on high-DPI displays
  - MSW: Fix visual glitches when changing the selected site in the Site Manager
  - When creating a new tab, the pane sizes are now inherited from the previous tab.
  - macOS: Additional fixes for handling Cmd+V, Cmd+C and Cmd+X in text input controls
  - Refactored internal settings and option handling
* Wed May 20 2020 ecsos <ecsos@opensuse.org>
- Update to 3.48.1
  * Bugfixes and minor changes:
  - If FileZilla is configured to restore open tabs on startup,
    the directory trees no longer shrink in size
- Changes from 3.48.1-rc1
  * Fixed vulnerabilities:
  - MSW: The settings directory is now initially created with
    tight permissions restricted to the user's account.
    Previously the directory could have had inherited too wide
    permissions if a custom location outside the user's profile
    directory had been preconfigured.
  * New features:
  - Redesigned certificate dialog
  - During directory comparison and comparative search,
    Ctrl+Shift+A can now be used to select only the highlighted
    files
  * Bugfixes and minor changes:
  - Fixed import of settings
  - Fixed local file editing if the option to track local file
    changes had been disabled
  - Fixes to storing associations
* Wed May 13 2020 ecsos <ecsos@opensuse.org>
- Update to 3.48.0
  * Fixed vulnerabilities:
  - Custom associations for file extensions containing spaces
    were not saved correctly
- Changes from 3.48.0-rc1
  * New features:
  - Overhaul of file associations for editing files. The setting
    to inherit system associations has been removed. When first
    editing a type of file with no default editor set, a dialog
    is shown asking which editor to use. The system associatio,
    if it exists, is a choice in this dialog.
  * Bugfixes and minor changes:
  - SFTP: Re-added support for AES-GCM which was accidentally
    removed in 3.46.1
  - Fixes for comparative search leaving the program in an
    inconsistent state when closing the dialog during an ongoing
    search
* Thu Mar 12 2020 ecsos@opensuse.org
- Update to 3.47.2.1
  * Bugfixes and minor changes:
  - macOS: Potential fix for clipped text labels on a few systems
  - SFTP: Backported selected fixes from developement versions of
    PuTTY
  - Fixed value range for directional transfer limits
  - Fixed layout issues if changing to/from comparative search
- Changes from 3.47.1
  * Bugfixes and minor changes:
  - Fixed regression loading advanced site parameters
- Changes from 3.47.0
  * Bugfixes and minor changes:
  - Fix visual glitches adding/removing filter rows
  - MSW: Limit amount of text that can be entered in spin
    controls
* Fri Feb  7 2020 ecsos@opensuse.org
- Update to 3.46.3
  * Bugfixes and minor changes:
  - SFTP: Fixed handle leak on Windows
  - SFTP: Remote paths were not fully resolved on all operations
- Changes from 3.46.2
  * Bugfixes and minor changes:
  - SFTP: Fixed a regression connecting using
    a password-protected keyfile
- Changes from 3.46.1
  * Bugfixes and minor changes:
  - Fixed a crash if an FTP server sends too long response lines
  - Building and running FileZilla now depends on libfilezilla
    >= 0.19.3 (https://lib.filezilla-project.org/), this fixes
    a few issues with the new speed limiting code
  - SFTP components have been updated and are now based on
    PuTTY 0.73
- Run spec-cleaner.
* Tue Nov 26 2019 ecsos@opensuse.org
- Update to 3.46.0
  * Bugfixes and minor changes:
  - Fixed a rare crash if closing FileZilla the very same moment
    a connection or transfer requests user attention
- Update to 3.46.0-rc1
  * New features:
  - Show an error message in the local directory listing if the
    user lacks permission to show the directory
  * Bugfixes and minor changes:
  - Local filelist status bar is now reset if accessing a local
    directory fails
  - macOS: Work around an a bug in macOS 10.15 (Catalina) where
    closing a dialog shown from a timer can result in temporary
    freezes
  - Refactored speed-limiting code
  - Building and running FileZilla now depends on
    libfilezilla >= 0.19.1 (https://lib.filezilla-project.org/)
* Mon Nov  4 2019 ecsos@opensuse.org
- Update to 3.45.1
  * Bugfixes and minor changes:
  - Fixed sorting issues in the directory trees
- Update to 3.45.0
  * Bugfixes and minor changes:
  - Updated translations
- Update to 3.45.0rc1
  * New features:
  - If checking for updates cannot be performed for a prolonged
    time, users are warned about using an outdated version
  * Bugfixes and minor changes:
  - Performance improvements if expanding or refreshing a
    directory with thousands of direct subdirectories in the
    directory trees
  - Fixed prefix search in Site Manager
  - macOS: Fix password pasting using Cmd+V
  - Minor performance improvements deleting many thousands of
    files
* Sun Aug 25 2019 ecsos@opensuse.org
- Update to 3.44.2
  * Bugfixes and minor changes:
  - MSW: Fixed a crash if using predefined sites through
    fzdefaults.xml
  - Fixes to protocol selection glitches in the Site Manager
  - Increase maximum length of response lines when using FTP
- Update to 3.44.1
  * Bugfixes and minor changes:
  - Fixed a regression introduced in 3.44.0-rc1 breaking support
    for insecure servers
- Update to 3.44.0
  * Bugfixes and minor changes:
  - Fixed export in context menu of Site Manager to handle
    multiple selected items
* Sat Jun 29 2019 ecsos@opensuse.org
- Update to 3.43.0
  * Fixed vulnerabilities:
  - Filenames containing double-quotation marks were not escaped
    correctly when selected for opening/editing. Depending on the
    associated program, parts of the filename could be
    interpreted as commands.
  * Bugfixes and minor changes:
  - Added a second layer of authentication to the update
    mechanism
- Update to 3.43.0-rc2
  * Bugfixes and minor changes:
  - Rebuilt against libfilezilla 0.17.1
- Update to 3.43.0-rc1
  * Bugfixes and minor changes:
  - macOS: Minimum required macOS version has been increased to
    10.11 (El Capitan)
  - *nix: Official Linux binaries are now built for Debian 10
    (Buster)
  - Building FileZilla now requires a C++17 compiler
  - Building and running FileZilla now depends on
    libfilezilla >= 0.17.0 (https://lib.filezilla-project.org/)
  - When using SFTP, fix fallback to password authentication on
    a server refusing a password-protected key
  - Fix HTTP proxy support
  - *nix: Improve resolution of program icon
* Wed May 15 2019 ecsos@opensuse.org
- Fix build error for Leap.
- Run spec-cleaner.
* Fri May 10 2019 Michael Ströder <michael@stroeder.com>
- Updated BuildRequires to libfilezilla 0.16.0+
* Thu May  9 2019 Michael Ströder <michael@stroeder.com>
- Update to 3.42.1
  * Bugfixes and minor changes:
  - OS X: Fix a compatibility issue with macOS 10.13
- Update to 3.42.0
  * Bugfixes and minor changes:
  - Fixed a potential crash if the first-launch welcome dialog
    is shown at an inopportune moment
  - Fixed display of subject and issuer details in the
    certificate verification dialogs with some certificates
  - Official binaries are now built againt GnuTLS 3.6.7, minimum
    required GnuTLS version to build FileZilla is now 3.5.7
- Update to 3.42.0-rc1
  * Bugfixes and minor changes:
  - Switching from using a master password to not saving
    passwords at all no longer requires entering the master
    password
  - *nix: Fixed support for internationalized domain names on
    systems having AI_IDN when using SFTP
  - Fixed an assertion after importing a manipulated queue file
  - When importing sites, any imported passwords are now
    immediately protected/deleted depending on the password
    protection settings
  - The ability to import Sitem Manager entries from antique
    FileZilla 2, last updated over a dozen years ago, has been
    removed
* Mon Mar 18 2019 Michael Ströder <michael@stroeder.com>
- Update to 3.41.2
  Backport a security fix from PuTTY 0.71 affecting SFTP connections:
  Fix an integer overflow in the RSA key exchange preceeding
  host key verification
- fix for boo#1133776
  Securtiy fix for CVE-2019-5429.
  http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2019-5429
* Fri Mar  8 2019 seanlew@opensuse.org
- Update to 3.41.1
  * Bugfixes and minor changes:
  - Fix a regression introduced in 3.41.1 with slow FTP servers
    needlessly waiting for a bidirectional shutdown of the data
    connection during downloads
- Update to 3.41.0
  * Bugfixes and minor changes:
  - MSW: Fix an issue with failing uploads due to the operating
    system not gracefully closing TCP connections contrary to the
    documented behavior
  - MSW: Fix compilation flags for wxWidgets to no longer include
    useless XP compatibility
- Update to 3.41.0-rc1
  * Bugfixes and minor changes:
  - Fixed crash if adding a bookmark with the current connection
    not yet having a Site Manager entry
  - Fixed a rare crash if closing FileZilla while a recursive
    chmod operation is still in progress
  - Fixed a rare crash if starting directory comparison on an
    empty directory without logical parent
  - Fixed a rare crash on changing the file list sort order when
    the focused item index has previously become invalid
  - Restrict the maximum length of regular expressions in filter
    conditions due to bugs in some implementations of the
    C++ Standard Library causing crashes
  - OS X: Fixed crash if the path of a file dropped on FileZilla
    cannot be obtained
  - Fixed order in which directories helper tools and data files
    are searched for
  - Fixed a rare crash if closing tab during an ongoing recursive
    directory deletion
* Mon Jan 28 2019 ecsos@opensuse.org
- Update to 3.40.0
  * Bugfixes and minor changes:
  - Official binaries are now linked against GnuTLS 3.6.6
- Update to 3.40.0-rc2
  * Bugfixes and minor changes:
  - Fix regression introduced in rc1 where adding files to queue
    creates extra server items if the connection was established
    through the Site Manager
- Update to 3.40.0-rc1
  * New features:
  - Added TLS 1.3 support by linking official binaries against
    GnuTLS 3.6.5
  - Refactored how sites and servers are being represented
    internally to fix issues trigged by renaming sites in the
    Site Manager
  * Bugfixes and minor changes:
  - Fix display of server names containing ampersands in several
    dialogs
  - Fix regular expression filter in the quick search panel
  - Fix a crash if files are added to the queue when there are
    already files for multiple different servers in the queue
  - Fix a crash applying filters when there are no selected files
    and the focused item is past the new file count
  - Fix a crash if emptying the queue while a directory creation
    item is active
  - Fix a potential crash if FileZilla is being closed the moment
    a delayed dialog has already been created but before it is
    shown.
* Sat Dec  1 2018 ecsos@opensuse.org
- Update to 3.39.0
  * Bugfixes and minor changes:
  - Fix timestamps of newly created empty files on the server if
    the option to preserve timestamps is set
- Update to 3.39.0-rc1
  * New features:
  - The down button on the keyboard now opens the quickconnect
    history dropdown menu if the quickconnect bar has the input
    focus
  - The down button on the keyboard now opens the search options
    if the quick search dialog has the input focus
  * Bugfixes and minor changes:
  - Refactored how close notifications were handled in the
    network code
  - Fixed saving of the 'not equal' and 'less than' conditions
    for size filters
  - Fixed regular expression filters not respecting the
    case-sensitivity checkbox in all situations
  - Restore context menu item to delete file in local file search
* Sat Nov  3 2018 ecsos@opensuse.org
- update to 3.38.1
  * Bugfixes and minor changes:
  - Fixed crash if transferring three or more files in parallel
    when speed limits are enabled
* Sat Oct 27 2018 ecsos@opensuse.org
- update to 3.38.0
  * Bugfixes and minor changes:
  - Updated translations
- update to 3.38.0-rc1
  * New features:
  - Refreshing remote file list while holding Ctrl now clears
    the remote directory cache for the current server
  - Changed default logon type if creating a new site in the Site
    Manager
  * Bugfixes and minor changes:
  - Fixed state of controles in the Site Manager when creating
    a new site after the previously viewed site
    has been - predefined
  - Fixed dragging remote files to queue
  - Building and running FileZilla now depends on
    libfilezilla >= 0.15.0 (https://lib.filezilla-project.org/)
  - Improve compatibility with GnuTLS 3.6.x
  - Fix building with automake >= 1.16.0
* Sat Oct 13 2018 ecsos@opensuse.org
- update to 3.37.4
  * Bugfixes and minor changes:
  - MSW: Fix regression introduced in 3.37.3 with moving files
    locally using drag&drop
- update to 3.37.3
  * Bugfixes and minor changes:
  - Fix issues with directory creation when uploading many files
    in parallel
- drop filezilla-3.22.2-buildinfo-no-date.patch
* Mon Sep 24 2018 ecsos@opensuse.org
- update to 0.37.1
  * Bugfixes and minor changes:
  - Local path is no longer forgotten when leaving synchronized
    browsing mode
- update to 0.37.0
  * Bugfixes and minor changes:
  - Fix remote target path if uploading files through the search
    dialog
- update to 0.37.0-rc1
  * New features:
  - Use a cache for the system trust store to speed up connecting
    establishment on systems with huge certificate revocation
    lists in the system trust store
  * Bugfixes and minor changes:
  - Fixed bug in GnuTLS causing crashes on connection
    establishment
  - Fixed enabled state of controls in the Site Manager if
    switching to a protocol not supporting the previously
    selected logontype
* Wed Aug 29 2018 ecsos@opensuse.org
- update to 3.36.0
  * Bugfixes and minor changes:
  - Fix --site-manager command-line argument
  - Fix potential crash with malformed directory listings
  - Fix potential crash if opening/closing tabs or starting the
    queue while directories are being renamed or deleted
- update to 3.36.0-rc1
  * New features:
  - Ask for explicit confirmation prior to falling back
    to insecure plaintext FTP if a server refuses to use TLS
  - Warn if an FTP server refuses TLS that is known from previous
    connections to be capable of TLS
* Mon Aug  6 2018 ecsos@opensuse.org
- update to 3.35.2
  * Bugfixes and minor changes:
  - Fix functionality of --site and --local command-line options
  - MSW: Fix local rename not updating file list
  - OS X: Fix compatibility with old CPUs not supporting SSE4
- update to 3.35.1
  * Bugfixes and minor changes:
  - Fix context menu in search dialog
- update to 3.35.0
  * New features:
  - Improved appearance of activity indicators, sort direction
    indicators, and quick search panel buttons on high-DPI
    displays
- update to 3.35.0-rc2
  - OS X: Fix dependency problem in build system
- update to 3.35.0-rc1
  + Add option to settings dialog to have FileZilla restore tabs
    and connections after a restart
  - Fix initial size of Site Manager being too small on some
    systems
* Tue Jun 19 2018 ecsos@opensuse.org
- update to 3.34.0
  * New features:
  - After deleting files, the focus rectangle now stays near
    the previously deleted file
- update to 3.34.0-rc1
  * New features:
  - Refactoring of the Site Manager internals
  - Moved protocol selection to the top in the Site Manager
  - Adjusted spacing in the Site Manager
  - Slightly reduced height of certificate details dialog
  * Bugfixes and minor changes:
  - MSW: Properly quote the uninstall command in the registry
  - Updated builtin pugixml to version 1.9
* Tue May  8 2018 ecsos@opensuse.org
- update to 3.33.0
  * Bugfixes and minor changes:
  - MSW: Microsoft broke the ICopyHook interface in Windows 1803.
    Until Microsoft fixes the bug in Windows, drag & drop from
    FileZilla into Explorer will not work on Windows 1803.
- update to 3.33.0-rc1
  * New features:
  - The contents of the transfer queue can now be sorted
  - SFTP: Support key files encrypted with aes256-ctr, e.g. as
    created by OpenSSH 7.6 and later
  * Bugfixes and minor changes:
  - SFTP: Fix preserve timestamps menu option
* Mon Apr 16 2018 ecsos@opensuse.org
- update to 3.32.0
  * New features:
  - Further SFTP performance improvements
- update to 3.32.0-rc1
  * New features:
  - The Site Manager no longer shows controls not applicable to
    the selected protocol
  - Dynamically disable menu items if the used protocal does not
    support the corresponding functionality
  - Speed up listing large directories over SFTP
  * Bugfixes and minor changes:
  - Fix state of case sensitivity checkbox in the filter edit
    dialog if no filter has been selected
* Mon Mar  5 2018 ecsos@opensuse.org
- Update require libfilezilla to 0.12.1 as described in configure
* Sat Feb 24 2018 ecsos@opensuse.org
- update to 0.31.0
  * New features:
  - Allow trusting all subject alternative names (SAN) in a
    certificate if the current hostname matches the certificate
  * Bugfixes and minor changes:
  - OS X: Fix file lists becoming inresponsive when a file rename
    edit box is discarded by clicking to the right of the last
    column in the file list
  - Fix rare crash during directory removal
  - Fix rare crash in the transfer queue
* Thu Jan 25 2018 ecsos@opensuse.org
- update to 0.30.0
  * Bugfixes and minor changes:
  - Add additional logging if autoupdate mechanism fails
- update to 3.30.0-rc1
  * New features:
  - In the search dialog local files can now be deleted or opened
  - The root node in the remote directory tree is now expanded
    by default
  * Bugfixes and minor changes:
  - Fix uploading from search dialog
  - Fix formatting of filename in rename dialog
  - MSW: Fix installer crash if an update installation is started
    with the updated version having been installed
* Sun Nov 12 2017 ecsos@opensuse.org
- update to 0.29.0
  * Bugfixes and minor changes:
  - Fix activity indicators not working after the update check
    has been run
- update to 0.29.0-rc1
  * New features:
  - Added new quick search filter to file lists,
    accessed through Ctrl+F
  - FTP over TLS: Mismatched hostnames are now highlighted in red
    in the certificate verification dialog
  - Filters using regular expressions can now be case-insensitive
  * Bugfixes and minor changes:
  - Explicitly wait for the settings to be written to disk before
    removing the backup file to prevent loss of data in case of
    system crashes
* Mon Oct  2 2017 ecsos@opensuse.org
- update to 3.28.0
  * New features:
  - *nix: Official Linux binaries are now built for Debian 9
    (Stretch)
  * Bugfixes and minor changes:
  - Do not disable password saving settings if fzdefaults.xml
    contains a kiosk mode setting of 0.
- update to 3.28.0-rc1
  * New features:
  - Add "Close once" as queue completion action
  * Bugfixes and minor changes:
  - Fixed crash if FileZilla is forced to close, e.g. when the
    system is shutting down, while there are open dialogs
  - If the transfer queue asks for a password and the password
    dialog is canceled the queue processing is now stopped
  - OS X, *nix: Improve detection of invalid character encodings
    in local filenames
  - Fix potential crash expanding directory tree items while
    changing selections
* Sun Aug 20 2017 ecsos@opensuse.org
- update to 3.27.1
  * Fixed vulnerabilities:
  - Change client identification string if connecting with SFTP
    due to OpenSSH disregarding the supported ciphers announced
    by the client, resulting in less secure algorithms being
    chosen by OpenSSH.
  * Bugfixes and minor changes:
  - MSW: Improve handling of NTFS reparse points
  - MSW: If running the installer with /S, previous versions
    where not uninstalled prior to the new version being
    installed
  - MSW: The installer can be run with /quiet for a semi-silent
    installation
  - OS X, *nix: Potential fix for a rare crash if changing local
    directories while the local directory list is being updated
    and vice versa.
- remove patch putty-no_DATE_and_TIME_.patch because it is now in
  upstream
* Thu Aug 10 2017 ecsos@opensuse.org
- add COPYING file to %%doc
* Sat Aug  5 2017 ecsos@opensuse.org
- update to 3.27.0.1
  * Bugfixes and minor changes:
  - MSW: Add misssing file to .zip binary package
  - MSW: Fix toolchain issues breaking the shell extension
- update to 3.27.0
  * Bugfixes and minor changes:
  - SFTP components have been updated and are now based on
    PuTTY 0.70
- update to 3.27.0-rc1
  * New features:
  - Support for the Storj decentralized cloud storage provider
  * Bugfixes and minor changes:
  - MSW: Fix display of file type of directories if the directory
    name contains a dot
  - Fix assertion if entering an invalid protocol prefix into the
    host field on the quickconnect bar or in the site manager
  - Improve error message if TLS certificate verification fails
    due to a missing stapled OCSP resonse
  - Building and running FileZilla now depends on
    libfilezilla >= 0.10.0 (https://lib.filezilla-project.org/)
* Thu Jun 15 2017 ecsos@opensuse.org
- update to 3.26.2
  * Bugfixes and minor changes:
  - Fixed crash if using master passwords and decrypting very
    long passwords
* Sun Jun  4 2017 ecsos@opensuse.org
- update to 3.26.1
  * Bugfixes and minor changes:
  - Fixed crash if changing password settings and the
    Site Manager contains subdirectories
  - *nix: Fixed saving of sites having more than one
    site-specific bookmark
- update to 3.26.0
  * Bugfixes and minor changes:
  - When changing or removing the master password, update
    protected credentials of server items in the transfer queue
  - Fix display of remember checkbox when showing the password
    entry dialog for sites that have no username set and are
    using the "Ask" logon type
  - Some icons were missing in the Windows .zip binary archive
- update to 3.26.0-rc1
  * New features:
  - Passwords can now be stored encrypted, protected with
    a master password
  - Building and running FileZilla now depends on
    libfilezilla >= 0.9.2 (https://lib.filezilla-project.org/).
  - Building and running FileZilla now depends on
    wxWidgets >= 3.0.3
* Tue May  2 2017 ecsos@opensuse.org
- update to 3.25.2
  * Bugfixes and minor changes:
  - SFTP components have been updated and are now based on
    PuTTY 0.69
  - Fixed potential stall during the final listing operation when
    finishing a queue which contained uploads
- update to 3.25.2-rc1
  * Bugfixes and minor changes:
  - Fix crash if filters.xml has become corrupted
  - Fix FTP proxy support
  - Fix sending of FTP keep-alive commands
  - MSW: Windows Vista is no longer supported
  - MSW: File and directory icons now also appear on systems that
    have no Windows directory
- update to 3.25.1
  * Bugfixes and minor changes:
  - OS X: Fixed a crash if connecting to old servers not
    supporting UTF-8
  - Fixed timeout detection
* Wed Mar 15 2017 ecsos@opensuse.org
- update to 3.25.0
  * New features:
  - OS X: The minimum required OS X version is now 10.9
  * Bugfixes and minor changes:
  - OS X: Disable App Nap during transfers and other operations
  - OS X: Downloaded updates are now stored in the Downloads
    directory
  - OS X: Fix initial toolbar state on startup if it was hidden
    when FileZilla was last closed
  - Fix reconnect delay logic which broke in 3.25.0-beta1
  - Fix piecewise creation of remote paths using FTP which broke
    in 3.25.0-beta1
- update to 3.25.0-rc1
  * Bugfixes and minor changes:
  - Fix encryption selection for FTP in the Site Manager which
    broke in 3.25.0-beta1
  - Small changes to error message texts
- update to 3.25.0-beta1
  * New features:
  - Major refactoring of the FileZilla internals.
  * Bugfixes and minor changes:
  - Scale width of fields in the status line control on high-DPI
    displays
  - Fix duplicate mnemonic in "Files currently being edited"
    dialog.
- Drop patch filezilla-3.24.1-config_parse_error.patch because now
  in upstream
* Thu Feb 23 2017 ecsos@opensuse.org
- update to 3.24.1
  * Bugfixes and minor changes:
  - Fixed rendering icons in the remote directory tree when DPI
    scaling is enabled on Windows Vista and some Windows 7
    machines
  - SFTP components have been updated and are now based on
    PuTTY 0.68
  - Updated builtin pugixml to version 1.8
- Add patch filezilla-3.24.1-config_parse_error.patch to prevent
  build error.
* Sun Jan 15 2017 ecsos@opensuse.org
- update to 3.24.0
  * Bugfixes and minor changes:
  - Fixed a possible crash if sending FTP commands fails during
    a directory listing operation
  - *nix: Fixed a scrolling issue in the message log if wxWidgets
    is built against GTK3
- update to 3.24.0-rc1
  * New features:
  - The context menu for remote file search results now has
    a "Copy URL(s) to clipboard" item
  - Alt+number can now be used to switch between tabs in addition
    to Ctrl+number
  - SFTP hostkey fingerprints are now also shown as base64
    encoded SHA256 hashes to match the new format displayed by
    OpenSSH
  * Bugfixes and minor changes:
  - Errors at the end of SFTP transfers now correctly result in
    transfer failures instead
  - Cancelling synchronized browsing questions no longer prevents
    further directory changes
  - Fix display issues for the filter conditions dialog
  - Fix deleting multiple extensions on the filetype page in the
    settings
  - OS X: Do not open dialogs while already processing an event,
    e.g. while a context menu is open
* Tue Dec  6 2016 ecsos@opensuse.org
- update to 3.23.0.2
  * Bugfixes and minor changes:
  - Key file paths entered in the Site Manager are now saved to
    corresponding server entries in the transfer queue
  - MSW: Work around a bug in wxWidgets causing bad icons in the
    remote directory tree due to wxImageList::GetBitmap
    errorneously stripping the alpha channel from images
  - Allow relative paths and environment variables in the
    "Cache directory" setting.
- update to 3.23.0.1
  * Bugfixes and minor changes:
  - Work around a bug in wxWidgets that has been causing a
    virtually infinite loop when deleting toolbar buttons
- update to 3.23.0
  * Bugfixes and minor changes:
  - Speed up icon scaling and cache scaled icons for faster
    subsequent loading. The cache directory can be changed
    through fzdefaults.xml using the "Cache directory" setting
  - OS X: Fixed icon display on high-DPI displays in a few more
    dialogs
  - Loading a corrupted layout.xml or search.xml no longer shows
    an error message, these files are now silently overwritten
  - MSW: Fixed a regression where UNC paths where not handled
    correctly as config location in fzdefaults.xml
- update to 3.23.0-rc1
  * New features:
  - New high-resolution icons
  - Improvements to the sizing of icons and other user interface
    elements on high-DPI displays. For technical reasons,
    existing theme settings have been reverted to their default
    values. They can be changed again in the settings dialog.
  - Make use of the Unix.ownername and Unix.groupname facts for
    MLSD if available
  * Bugfixes and minor changes:
  - The bookmarks menu updates again after changing global
    bookmarks
  - Adding a site to the Site Manager as part of adding a
    site-specific bookmark no longer fails if sitemanager.xml
    does not yet exist
  - Strip byte order marks at the beginning of directory listings
  - Add an option to filezilla.xml to control cache ttl
* Sun Nov 20 2016 ecsos@opensuse.org
- update to 3.22.2.2
  * Bugfixes and minor changes:
  - Fixed trimming of FEAT response lines leading to incorrectly
    detected server features
- update to 3.22.2.1
  * Bugfixes and minor changes:
  - OS X: Rebuilt to work around a nasty bug in XCode: Even when
    linking with -Wl,-no-weak-imports it links against functions
    not available on older OS X versions
  - Fixed a crash on exotic servers only implementing factless
    MLST/MLSD
- update to 3.22.2
  * Bugfixes and minor changes:
  - Tuned appearance of progress bar in transfer queue
- update to 3.22.2-rc2
  * Bugfixes and minor changes:
  - SFTP: Renaming a file or directory where the new name already
    refers to a directory no longer moves the file into this
    directory.
  - Fix regression from -rc1 with custom ports in the
    quickconnect bar
  - Fix regression from -rc1 parsing the EPSV reply
- update to 3.22.2-rc1
  * New features:
    + Building and running FileZilla now depends on
    libfilezilla >= 0.8.0 (https://lib.filezilla-project.org/).
  * Bugfixes and minor changes:
  - Non-existing key files are no longer silently dropped from
    the SFTP page in the settings dialog
  - Further abbreviate log output if transferring files using
    SFTP
  - Generic proxy usernames and passwords containing non-ASCII
    characters are again handled correctly
  - Fixed an assertion if Ctrl+A is pressed in an empty file list
  - *nix: Fixed color of status message in the message log
  - *nix, OS X: Fixed an assertion adding files to the queue
    after having selected a large range of items
  - *nix, OS X: Fixed an assertion due to a timing issue when
    renaming local files
- rebase buildinfo-no-date.patch
  - Drop Patch filezilla-3.5.3-buildinfo-no-date.patch
  - Add Patch filezilla-3.22.2-buildinfo-no-date.patch
* Sat Oct  8 2016 ecsos@opensuse.org
- update to 3.22.1
  * Bugfixes and minor changes:
  - OS X: Work around a nasty bug in XCode where programs
    explicitly compiled for older versions of OS X were silently
    pulling in features exclusive to the new version, resulting
    in crashes at runtime
  - Fixed a potential crash when using SFTP
* Sun Oct  2 2016 ecsos@opensuse.org
- update to 3.22.0
  * Bugfixes and minor changes:
  - Bookmarks with the "Directory comparison" checkbox set now
    work correctly
  - MSW: Fix background clearing issue on the size format
    settings page
  - MSW: Toggling the log timestamp option no longer results in
    wrong log colors
  - Fix for premature queue completion action
- update to 3.22.0-rc1
  * New features:
  - Directory listing filters can now be exported and imported
  - Added the "not all" filter match type to filter out all items
    not matching all conditions
  - Added the "not all" search match type to search for all items
    not matching all conditions
  - Building and running FileZilla now depends on libfilezilla
    >= 0.7.0 (https://lib.filezilla-project.org/).
  - Building and running FileZilla now depends on GnuTLS
    >= 3.4.15
  * Bugfixes and minor changes:
  - Speed up creation of socket and file i/o threads through the
    use of a thread pool
  - Replace invalid characters in filenames when calculating the
    local filename for editing remote files
  - The updater can now handle HTTPS servers that redirect to
    other HTTPS servers
  - SFTP: Try password based login if a password-protected
    keyfile is rejected by the server instead of failing the
    login
  - MSW: Tee shell extension now supports long paths on
    Windows 10
* Thu Aug 25 2016 ecsos@opensuse.org
- update to 3.21.0
  * Fixed vulnerabilities:
  - Fixed a string format vulnerability introduced in 3.20.0-rc1
    when listing directories using SFTP
  * New features:
  - SFTP: Added support for AES-GCM ciphers as implemented in
    OpenSSH
  - OS X: Ctrl+Tab and Ctrl+Shift+Tab can now be used to switch
    forward and backward between opened tabs
* Thu Aug  4 2016 ecsos@opensuse.org
- update to 3.20.1
  * Bugfixes and minor changes:
  - Fixed rename file exists action on downloads
  - Fixed possible crash if disabling log abbreviation
  - Official binaries now link against a patched version of
    GnuTLS so that a better error message can be printed on
    broken servers that send malformed certificate chains
- update to 3.20.0
  * New features:
  - Display error message if entering a non-existing path on
    local file search
  - Building and running FileZilla now depends on
    libfilezilla >= 0.6.1 (https://lib.filezilla-project.org/).
- update to 3.20.0-rc1
  * New features:
  - Building and running FileZilla now depends on
    libfilezilla >= 0.6.0 (https://lib.filezilla-project.org/).
  - Building and running FileZilla now depends on GnuTLS 3.4.0
    or higher
  * Bugfixes and minor changes:
  - Fixed regression introduced in 3.19.0-rc1, reconnecting again
    uses the last used remote directory instead of the initial
    default remote directory
  - Fixed crash if creating a new site via the bookmarks dialog
  - Queuing remote directories for transfer no longer exits
    comparison mode
  - Fixed a rare crash using FTP over TLS if the control
    connection fails at the same time the data connection gets
    established
  - Entering invalid regular expressions in filter and search
    conditions now shows an error message
  - Fixed title of search dialog
  - Stricter certificate chain validation to supplement the Tofu
    model
  - *nix: Fix initial size of Site Manager dialog with some GTK
    versions
* Tue Jun 28 2016 ecsos@opensuse.org
- update to 3.19.0
  * New features:
  - Building FileZilla now depends on libfilezilla >= 0.5.3
    (https://lib.filezilla-project.org/).
  * Bugfixes and minor changes:
  - Fixed context menu in search dialog if not connected to
    server
  - OS X, *nix: Fix displayed text in file list status bar if
    selecting a single item in the file list out of multiple
    already selected items
- update to 3.19.0-rc1
  * New features:
  - In the Site Manager a background colour for sites can now be
    selected
  - Open tabs can be re-arranged using drag&drop
  * Bugfixes and minor changes:
  - Fixed copying URLs of multiple selected files to clipboard
  - Setting remote file timestamps did not take timezone offsets
    configured through the Site Manager into account
* Sat May 28 2016 ecsos@opensuse.org
- update to 3.18.0
  * Bugfixes and minor changes:
  - Small fixes to local file search
  - Fixed a regression introduced in 3.18.0-rc1 when formatting
    hostnames for display
- update to 3.18.0-rc1
  * New features:
  - The search functionality can now also be used to search local
    file
  - Reduced CPU consumption of adding files to the list of search
    results
  - Opening the remote context menu while holding shift allows
    copying URLs to clipboard that include the password
  - Added an option to the configuration file through which
    initiating drag&drop can be disallowed
  - Reduced memory footprint of some data structures
  - Building FileZilla now depends on libfilezilla >= 0.5.2
    (https://lib.filezilla-project.org/).
  * Bugfixes and minor changes:
  - The remote file list context menu no longer shows
    inapplicable entries while files are being added to queue
  - Fix date validation in filter and search conditions
- Drop filezilla-wxstring.patch because no more compatible
* Tue May 10 2016 ecsos@opensuse.org
- update to 3.17.0.1
  - SFTP: Fixed resuming SFTP transfers
  - MSW: Loading the system default locale no longer fails on
    systems that have any English locale installed, yet do not have
    the US-English locale installed
  - Fixed crash if update dialog is opened at the very same moment
    FileZilla is being closed.
- Add Patch filezilla-wxstring.patch for wxString conversion bug.
* Wed Apr 27 2016 joerg.lorenzen@ki.tng.de
- update to 3.17.0
  - *nix: Removed a label on the filter dialog that doesn't apply
    to *nix builds.
  - Fix compilation if Nettle is installed in a custom location.
  - Fix potential issues with destruction order when closing
    FileZilla.
- update to 3.17.0-rc1
  + Recursivly queuing local files for upload now displays the
    progress below the local file list.
  + MSW: Use dynamic TCP send buffer sizes to improve upload
    speeds on high-latency connections.
  + SFTP: Use hardware-accelerated AES on x86_64 CPUs if available
    by using the AES implementation from Nettle instead of PuTTY.
  + Building FileZilla now depends on the Nettle library,
    version 3.1 or later.
  + Building FileZilla now depends on libfilezilla >= 0.5.0
    (https://lib.filezilla-project.org/).
  - MSW: The installer now warns if it detects old versions of
    FileZilla outside of the installation directory.
  - Improve compatibility with directory listings where midnight
    is represented as 24:00:00 of the prior day.
  - SFTP: Failed downloads due to write failures, e.g. due to a
    full disk, no longer show up as successful.
  - SFTP: Fix transfer failures if multiple transfers try to list
    the same directory.
  - SFTP: Updated PuTTY components.
  - FTP over TLS: Debug logs now contain additional information
    about the TLS handshake.
- Fixed putty-no_DATE_and_TIME_.patch.
* Thu Mar 17 2016 ecsos@opensuse.org
- update to 3.16.1
  - Updated PuTTY components
  - Updated translations
  - Official binaries now link against GnuTLS 3.4.10
  - Official binaries now link against SQLite 3.11.1
- update to 3.16.0
  + Make notification bubble on queue completion configurable
    though the queue's context menu
  + Selected queue completion action is now remembered,
    excluding the system shutdown/sleep actions.
  + Added new servertype to the Site Manager for servers using
    MS-DOS style paths with forward slashes as separators
  + Building FileZilla now depends on libfilezilla >= 0.4.0
    (https://lib.filezilla-project.org/).
  - Fixes for network configuration wizard leading to incorrect
    test result
  - Small fix for remembering queue completion actions
* Sun Feb 28 2016 ecsos@opensuse.org
- update to 3.15.0.2
  - Restore focused item if changing directory listing sort order
  - Fix restoring the column widths of the failed transfers tab in
    the queue when starting FileZilla
- update to 3.15.0.1
  - Fix for search dialog not displaying the results from the last
    visited directory of a search
- update to 3.15.0
  - no changes for *nix
- update to 3.15.0-rc1
  - Fix regression from 3.16.0-beta1 where extra data being
    appended to some downloaded files
  - Fix setting initial pane sizes when creating new tabs
  - Updated SFTP components from PuTTY
  - Official binaries now link against GnuTLS 3.4.8
  - Official binaries now link against SQLite 3.10.2
- update to 3.15.0-beta1
  - Building FileZilla now depends on libfilezilla 0.3.0
    (https://lib.filezilla-project.org/).
  - Added support for downloading and deleting multiple unrelated
    directories from the search dialog
  - *nix: Vastly speed up line-ending conversion when downloading
    files using the ASCII data type
  - Improved compatibility with broken servers omitting the
    mandatory 1yz reply to transfer commands
  - Fix handling of SFTP keyfiles with non-ASCII characters in
    their paths
  - Add missing directory comparison checkbox to new bookmark
    dialog
  - Updated built-in pugixml
- Drop filezilla-3.14.1_wxstring.patch: now in upstream
- Drop filezilla-3.14.1_xml.patch: now in upstream
- add BuildRequires libfilezilla
- add Requires libpugixml1 boo#966384
* Sat Jan 16 2016 ramaxlo@gmail.com
- Revert locale fixing script to the original version. The simplified
  script will cause
  pt_BR.po & pt_PT.po --> pt.po
  zh_CN.po & zh_TW.po --> zh.po
  one of them will be overwritten by the other, depending on which one
  is converted last.
* Sat Dec  5 2015 sor.alexei@meowr.ru
- In openSUSE Leap 42.1 set C++ ABI to the one wxWidgets uses
  (boo#958060).
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Only use explicit gcc5 for openSUSE Leap 42.1 (and older).
- Some spec simplifications.
- Update icon cache.
- Remove duplicate CXXFLAGS adding.
* Thu Nov  5 2015 aloisio@gmx.com
- Fixed compiler requirements, again.
* Tue Oct 27 2015 aloisio@gmx.com
- Added requirement for pugixml 1.7
* Tue Oct 27 2015 tchvatal@suse.com
- Simply rely on gcc-c++ from system as we won't build on older distros
  anyway
* Fri Oct 23 2015 aloisio@gmx.com
- Update to version 3.14.1 (2015-10-16)
  * For third-party builds, add configure flag to allow using
    system ciphers for FTP over TLS. Display a warning if an
    insecure cipher is negotiated as result of using system ciphers.
  * Fixed loading of the directory comparison flag for bookmakrs
    in the Site Manager
  * Changing the interface layout and icon theme no longer results
    in an inconsistent UI state
  * Some SFTP servers send additional information on errors. This
    information is now shown in the message log
  * If the local file cannot be opened on SFTP transfers FileZilla
    no longer automatically retries
  * Updated SFTP components from PuTTY
  3.14.0 (2015-09-16)
  * When connecting using SFTP, show an error message instead of
    silently failing when encountering an insecure cipher
  3.14.0-rc2 (2015-09-09)
  * Removing selected queue items is now faster
  * Reduced memory usage of queue
  * When connecting to hostnames with multiple IPs, reset timeout
    if trying the next address
  3.14.0-rc1 (2015-09-04)
  * Add support for password-protected SSH private keys
  * SSH private keys not in PuTTY's native format no longer need
    to be converted if they aren't password-protected
  * When using synchronized browsing, changing to a directory
    that does not exist on both sides now asks whether the missing
    directory should be created
  * SSH1 support for SFTP has been disabled
  3.13.1 (2015-08-24)
  * Fix SFTP component crashing on some combinations of encryption
    and key exchange algorithm
  * Fixed Ctrl+Shift+I shortcut to toggle filters
  * OS X: Fixed Ctrl+, shortcut to open settings dialog
  * Optimizations to reduce memory footprint
  * Build system fixes
- Added filezilla-3.14.1_wxstring.patch and filezilla-3.14.1_xml.patch
  to address build problems
- Dropped tinyxml requirements
* Fri Sep  4 2015 tchvatal@suse.com
- Add pugixml as dependency
* Fri Sep  4 2015 tchvatal@suse.com
- Version bump to 3.13.1:
  * Fix SFTP component crashing on some combinations of encryption and key
  * exchange algorithm
  * Fixed Ctrl+Shift+I shortcut to toggle filters
  * OS X: Fixed Ctrl+, shortcut to open settings dialog
  * Optimizations to reduce memory footprint
  * Build system fixes
  * Display home directory instead of root directory if the last used directory
  * does not exist
  * Larger initial size of main window if there is no stored size
  * Slightly increased size of page selection box in settings dialog
- Refresh patch:
  * filezilla-3.5.3-buildinfo-no-date.patch
* Sun Jul 19 2015 ecsos@opensuse.org
- version bump to 3.12.0.2:
  * Fix regression on servers that have MLSD facts disabled by
    default
- changes from 3.12.0.1:
  * Fix detection of UTF-8 support
  * Fix location of file list status bar, it was shifted by one
    pixel
* Fri Jul 10 2015 alarrosa@suse.com
- BuildRequire wxWidgets-3_0-devel in openSUSE 13.1, 13.2 and others
  (suse_version >= 1310) instead of wxWidgets-devel
* Fri Jul 10 2015 tchvatal@suse.com
- Version bump to 3.12.0:
  * Various small fixes all around
- Upstreamed patch:
  * filezilla-string-conversion.patch
* Sun Jun  7 2015 tchvatal@suse.com
- Version bump to 3.11.0.2:
  * Fix crasher during some server-client scenarios
  * Work with non-epoch time received from server
- Added patch:
  * filezilla-string-conversion.patch
* Wed May 27 2015 tchvatal@suse.com
- Version bump to 3.11.0.1:
  * Quite few small fixes around
* Tue Mar 31 2015 tchvatal@suse.com
- Version bump to 3.10.3:
  * Various small fixes
  * Merged suse patches
- Removed patches:
  * wxstring-conversions-fix.patch
  * fix-missing-include-fz-bug-10280.patch
* Sun Mar 22 2015 devel.suse@gmail.com
- Filezilla now requires wxWidgets >= 3.0.2
* Thu Mar 12 2015 tchvatal@suse.com
- Add patch to build with our wxwidgets wxstring-conversions-fix.patch
* Thu Mar 12 2015 tchvatal@suse.com
- Add patch fix-missing-include-fz-bug-10280.patch to fix build
* Tue Mar  3 2015 tchvatal@suse.com
- Version bump to 3.10.2:
  * In the XML files, passwords are now base64 encoded
  * The subject area in the certificate verification can now be scrolled if the
    certificate contains many alternative names
  * Many performance improvements
  * Various bugfixes
* Fri Oct  3 2014 tchvatal@suse.com
- Version bump to 3.9.0.5:
  * use wxwidgets-3.0
  * various layout fixes
  * assertion fixes
  * new additional iconset
- Accidentaly fix bnc#898879 by updating
* Thu Aug 14 2014 dimstar@opensuse.org
- Update to version 3.8.1:
  + OS X: Partial support for retina displays.
  + Fixed several small memory leaks.
- Changes from version 3.8.0:
  + Popup dialogs no longer automatically open if other dialogs are
    already open. This prevents FileZilla from becoming
    unresponsive on OS X
  + Fix calculation of current transfer speed. In some situations
    the transfer speed tooltip over the activity indicators showed
    negative speeds.
  + Fix handling of focus item in local directory listings if
    connecting to a site with a default local directory.
* Mon Jan 13 2014 tchvatal@suse.com
- Fix dependencies for the Factory build again and remove few
  useless lines.
* Fri Aug  9 2013 tchvatal@suse.com
- Version bump to 3.7.3
  - Full changelog: https://filezilla-project.org/changelog.php
  - Noteworthy changes:
  * Apply a fix for a security vulnerability in PuTTY as used in FileZilla to handle SFTP. See CVE-2013-4852 for reference.
  * Merge further fixes from PuTTY to address CVE-2013-4206, CVE-2013-4207, CVE-2013-4208
* Mon May 13 2013 tchvatal@suse.com
- Version bump to 3.7.0.1
  - Fix issues with bundled gnutls
  - Update translations
* Fri May 10 2013 tchvatal@suse.com
- Update to version 3.7.0. Changes since 3.6.0.2:
  - Show total transfer speed as tooltip over the transfer indicators
  - List supported protocols in tooltip of host field in quickconnect bar
  - Use TLS instead of the deprecated term SSL
  - Reworded text when saving of passwords is disabled, do not refer to kiosk mode
  - Improved usability of Update page in settings dialog
  - Improve SFTP performance
  - When navigating to the parent directory, highlight the former child
  - When editing files, use high priority for the transfers
  - Add label to size conditions in filter conditions dialog indicating that the unit is bytes
  - Ignore drag&drop operations where source and target are identical and clarify the wording in some drop error cases
  - Trim whitespace from the entered port numbers
  - Slightly darker color of inactive tabs
  - Ignore .. item in the file list context menus if multiple items are selected
  - Display TLS version and key exchange algorithm in certificate and encryption details dialog for FTP over TLS connections.
  - Fix handling of remote paths containing double-quotes
  - Fix crash when opening local directories in Explorer if the name contained characters not representable in the locale's narrow-width character set.
  - Fix a memory leak in the host key verification dialog for SFTP
  - Fix drag-scrolling in file lists with very low height
  - Don't attempt writing XML files upon loading them
  - Improve handling of legacy DDE file associations
  - Fix handling of HTTPS in the auto updater in case a mirror redirects to HTTPS
* Tue Mar  5 2013 nico.kruber@gmail.com
- Update to version 3.6.0.2. Changes since 3.5.3:
  - 3.6.0.2 (2012-11-29)
  * Fix problems with stalling FTP over TLS uploads
  * MSW: Minor performance increase listing local files
  - 3.6.0.1 (2012-11-18)
  * Fix problems with TLS cipher selection, including a bugfix
    for GnuTLS
  * Fix a crash on shutdown
  * Add log message for servers not using UTF-8
  * Small performance and memory optimizations getting file
    types
  * Improve formatting of transfer speeds
  - 3.6.0 (2012-11-10)
  * Fix a crash introduced since 3.5.3
  * IPv6-only hosts should no longer cause a crash in the
    network configuration wizard
* Thu Apr  5 2012 andreas.stieger@gmx.de
- add filezilla-3.5.3-buildinfo-no-date.patch
  fixing W: file-contains-date-and-time
* Tue Jan 10 2012 cstender@suse.com
- Update to version 3.5.3. Changes since 3.5.2:
  + Ctrl+Shift+O can be used to toggle between modification time and filesize based directory comparison
  - It is now possible to use custom passwords if using "anonymous" as user name
  - After un-hiding toolbar, update toolbar button states
  - Fix TLS compatibility issues with TLS 1.2 servers
  - MSW: Unset hidden attribute on FileZilla's settings files
  - Building FileZilla from source now requires wxWidgets 2.8.12 or higher.
* Wed Dec 14 2011 fisiu@opensuse.org
- Update to 3.5.2. Changes since 3.5.1:
    3.5.2 (2011-11-08)
  - Updated translations
    3.5.2-rc1 (2011-11-01)
    + Added option to open site manager on startup to the settings dialog
  - The "Don't save passwords" option was not being saved
  - The queue was not saved correctly if having items from multiple servers
  - Queue items with the lowest priority setting are now being restored again
  - Drag & Drop did not work with all saved sites if saving of passwords had been disabled
* Wed Oct 26 2011 fisiu@opensuse.org
- Update to 3.5.1. Changes since 3.4.0:
    3.5.1 (2011-08-28)
  - Add support for another rate variant of MVS style directory listings
    3.5.1-rc1 (2011-08-21)
    + Add menu item to hide toolbar
  - Don't save server list in kiosk mode 2
  - Fix for predefined sites not appearing in all circumstances
  - Fix typo in build script in detection of SQLite3
  - Fix character set conversion in desktop notification code
  - Merged upstream PuTTY changes for compatibility with PuTTY 0.61
  - Updated built-in TinyXML
    3.5.0 (2011-05-22)
  - Don't create queue.xml anymore if it does not exist
  - Several fixes to build system and environment
    3.5.0-rc2 (2011-05-15)
    + Added experimental setting to strip file revision upon download from VMS servers. Set "Strip VMS revisions" to 1 in FileZilla.xml to enable
  - The string coalescer benchmark debug option no longer crashes if benchmarking an empty string coalescer
    3.5.0-rc1 (2011-05-08)
    + The transfer queue is now stored in an SQLite database.
  - Fixed crash during shutdown of FileZilla
  - Clearing the queue when it was not yet fully populated no longer causes a crash
  - If using ask login type for a site and no username is given, the initial focus is now on the user box in the login dialog
* Fri Apr 29 2011 pth@novell.com
- Update to 3.4.0. Changes since 3.3.4.1:
    3.3.5-rc1 (2010-11-07)
    + FTP over TLS certificate store is now host-specific
    + MSW: Large-DPI awareness
    + Improved SFTP transfer speeds
    + FTP over TLS should prefer ciphers with longer key sizes
    + Add context menu entry to re-queue all files on the successful and
    failed queue tabs
  - Resuming of uploads was not working correctly in all cases
  - Correct remaining time calculation in queue
  - Do not show welcome dialog in kiosk mode 2
  - Do not offer option to permanently accept certificate in kiosk mode 2
  - Fix sorting by size in filelists with directory sort behavior set to
    inline
  - Directly save settings after importing from file
    3.3.5.1 (2010-11-21)
  - Permanently trusting certificates had no effect until FileZilla was
    restarted
  - Fix downloading of symbolic links to files
    3.4.0-beta1 (2011-01-09)
    + Added option to force use of insecure plain FTP to Site Manager
    + Kiosk mode option can now also be read from FileZilla.xml, with
    fzdefaults.xml having priority if setting exists in both files
  - Fix memory leak in directory cache
  - Compatibility with obscure DOS servers using forward slashes as path
    delimiter
  - Improve text wrapping engine
    3.4.0-rc1 (2011-03-20)
    + Add checkbox to settings dialog to not save passwords
    + Add timestamp columns to successful and failed queue tabs showing
    when the transfers completed or failed
  - Fixed infinite loop in TinyXML when loading settings from corrupt
    XML documents
  - Parsing MDTM reply now takes seconds into account
  - Compatibility with MVS listing containing PO-E type entries
  - Fix Resizing issues with manual transfers dialog
* Tue Apr  5 2011 pth@suse.de
- Fix typo in putty-no_DATE_and_TIME_.patch.
* Wed Dec 29 2010 sbrabec@suse.cz
- Compile with wxWidgets-wxcontainer, it does not compile with STL
  variant.
- Fixed invalid translation locales (filezilla#6514).
- Fixed project URL.
* Fri Nov  5 2010 pth@suse.de
- Update to 3.3.4.1:
  * Set a minimum size for column widths in directory lists and
    transfer queue.
  * Fix build-time check for system TinyXML.
  * Update german translation.
- Fix Provides and Obsoletes.
- Don't use __DATE__ and __TIME__ in included Putty source
  in order to reduce package rebuilds.
* Wed Mar 31 2010 pth@novell.com
- Use %%lang_package macro.
* Fri Mar 26 2010 pth@novell.com
- Refresh german message catalog and disambiguate messages
  marked fuzzy.
- Split off message catalogs into a -lang subpackage.
* Tue Mar 23 2010 per@osbeck.com
- update to v3.3.2.1
  - Remember location of update download directory
  - Cancel file renaming on actions that change the file list, such as changing sort order or performing a refresh
  - Cancel file renaming if starting a drag&drop operation
  - Filter invalid characters if downloading through double-clicking files or if adding from the search dialog
  - Fix site-specific bookmarks menu
  - The menu did not reflect initial value of preserve timestamp option properly
  - MSW: Keep FileZilla subdirectory in startmenu when updating, preserves custom order
  - MSW: Add AppID support to installer
* Tue Mar 16 2010 per@osbeck.com
- update to v3.3.2
- *nix: Add support for forward and backward mouse buttons
- Speed limits can be re-enabled on SFTP connections
- Changed settings did not come into effect unless FileZilla was restarted
- Small performance improvements
- Spelling fixes
- Rebuilt due to timer problems
- Speed limits can be quickly set using the menu and a new indicator in the status bar
- Display number of bytes transferred and duration of transfer in log
- MSW: React to back button of mouse in file lists
- Updated blukis icon set
- Refactored large parts of the toolbar and menubar code
- A race condition in the socket code could lead to crashes
- Fix connecting to addresses longer than 15 characters if using SOCKS proxy
- Get add to queue in local directory tree context menu working again
- Do not open request dialogs if user is holding a mouse button
- Forward all Ctrl+Tab key events to tab bar
- Do not report SFTP exitcodes that do not originate from the server
* Tue Feb 16 2010 seife@opensuse.org
- update to v3.3.1, to fix the build problems with newer libgnutls
* Thu Nov 22 2007 pth@suse.de
- Package renamed from FileZilla to filezilla because only the tarball
  is named with mixed case.
- Provide a filezilla-rpmlintrc
- Update to 3.0.3. Changes since 3.0.0.beta6:
  - Install some default filters if filters.xml missing in user's settings
    directory
  - Additional fixes for SFTP servers with nonstandard filename encodings
  - Automatic server timezone detection. Custom offset in the Site Manager
    may need to be adjusted. FTP only.
  - Option to preserve file timestamps on downloads (all protocols)
  - Option to preserve file timestamps on uploads on FTP servers supporting
    the MFMT command
  - Add transfer type (ascii/binary/auto) selection to transfer menu
  - Shorten very long filenames on file exists dialog
  - Attempt at working around broken routers and firewalls disconnecting
    the control connection of the transfer session on transfers
  - Deleting directories containing lots of files should be faster now
  - Disallow settings/site import from files located in the settings storage
    directory
  - Fix nullpointer dereference on non-UTF8 enabled SFTP servers
  - Fix button height inconsistencies on dialogs with certain artwork
    (e.g. Ubuntu 7.10)
  - Fix issue with message log not working properly
  - Experimental support for z/VM servers
  - Fix typo in option handling code. Due to this, settings for date/time
    formatting have been reset.
  - Fix performance problem if FileZilla gets started with message log
    hidden
  - Work around possible race conditions in SFTP input thread leading to
    crashes
  - Remote file viewing / editing
  - Display current server in window title
  - Don't remember incorrect password on SFTP connections with ASK
    logontype
  - Fix Makefiles so SFTP properly supports files > 2GB
  - Ascii filetype setting for extensionless files and dotfiles had
    negated effect
  - Fix error message if using multiple running instances save the
    settings at the same time
  - Fix parsing of very new files in directory listings if server is in a
    timezone ahead of the client
  - Fix range of timezone offset setting
  - Fix problems with remote path combobox if reconnecting after a
    disconnect
  - Display confirmation dialog if deleting file from remote directory
    tree context menu
  - Refresh remote directory listing after refreshing a single file
  - On very first startup, center FileZilla on screen
  - Fix parsing of settings or site XML data containing double, leading or
    trailing whitespace.
  - Settings to configure size, date and time formatting
  - Message log and queue visibility will be remembered
  - Custom action to perform after queue completion
  - Add some confirmation dialogs
  - Fix misplaced settings dialog
  - Fix problems with remembering pane size
  - Properly refresh local directory if downloading into newly created
    subdirectories
  - Fix issues with language set to Japanese
  - New application icon
  - Fix support for servers sending directory listing in yet another
    exotic format
  - Fix prefix search in list controls on wxGTK
  - Work around problem with wxSpinCtrl in site manager on wxGTK
  - Fix assertion on wxGTK if listing extensionless files
  - Fix buffer overflow if directory lisiting filters were enabled,
    causing FileZilla to crash.
  - Backspace key can be used to goes to parent directory in file lists
  - Fix file selection by entering filename prefix
  - Restore correct window size if FileZilla gets closed while minimized
  - Disable "Create directory" entry in remote filelist context menu
    while disconnected
  - Improve compatibility with SFTP servers using exotic listing formats
  - Fix queue scrolling
  - Remember Window size and position
  - Remember sort column and order of file lists
  - Additional icon set by Brian Lukis
  - Added .desktop file on *nix systems
  - If server is crippled and doesn't allow more than one connection
    (based on Sitemanager preference), primary browsing connection can be
    used by the transfer queue
  - Fix SSL transfers hanging if using speed limits
  - Compile fixes and compatibility improvements for various platforms
  - The usual assortment of small bugfixes, see changelog for details
  - Fix remotely triggered memory corruption if connection gets terminated
    during TLS handshake.
  - Column withs in all list views will be saved
  - Refresh local file list after a successful file transfer
  - Add context menu to remote directory tree
  - Make Site Manager resizable
  - Don't leave empty files behind on failed downloads
  - Fix retry and cache logic if transfer command fails with 5yz reply
  - Limit number of simultaneous connections did not work properly
  - Refresh listing after chmod
  - Fix upload of empty files over TLS connections
  - Improved queue
  - Import and export dialogs including import of Sitemanager data
    from legacy FZ 2.x
  - Tab key can be used to switch between panes
  - F6 toggles between quickconnect bar and local/remote path edit fields
  - Location of settings directory can be specified in fzdefaults.xml
  - Engine state could get mixed up if transfers failed
  - Transfer of empty files could incorrectly time out
  - Fix directory cache coherency if removing/renaming directories
  - Work around lack of thread-safety in wxWidgets causing random
    misbehaviour
  - Properly disconnect idle transfer engines after 30 seconds
  - Update selections if changing sort order of file lists
  - Various minor fixes
  - Add "View hidden files" option to server menu
  - Add dialog to clear private data
  - Performance improvements of message log
  - Avoid sending unnecessary TYPE commands
  - Updated TinyXML component, fixes problems with filenames
    containing ampersands or other special XML entities.
  - Don't retry connecting if user cancels new/changed hostkey
    notification
  - Fix data corruption on FTPS uploads
  - Implement speed limits
  - Last used local directory will be remembered
  - New option for the sorting of the filelists. Directories can be kept
    on top or sorted inline.
  - Display warning if detecting a Windows system with a networking bug
    confirmed by Microsoft
  - Right-clicking the Sitemanager button in the toolbar displays a popup
    menu with the sites for quick access. On Windows, a dropdown arrow got
    added.
  - Autocompletion did not work properly on GTK based systems
  - Uninstalling FileZilla on Windows should no longer leave registry keys
    behind
  - lots of small bugfixes
  - New optionspage to change layout of file and directory panes
  - Loading of predefined Sitemanager entries from fzdefaults.xml
  - UTF-8 support for SFTP, merged in upstream changes from PuTTY.
  - Ascii file FTP transfers should now work properly on non-Windows
    systems
  - Fix SFTP transfers of filenames containing the following
    characters: [ ] \ * ?
  - lots of small bugfixes and performance improvements
* Wed May 16 2007 pth@suse.de
- Fix comparison of pointer with string.
* Fri May  4 2007 pth@suse.de
- Initial package
